##  Automation 3: Relation Is Added
Automation Configuration Parameter | Configuration
---|---
Trigger (When) |
  * Fact Sheet Type: Application
  * Event: Relation Is Added
  * Fact Sheet Relation: IT Component


Conditions (If) | Configure optional conditions for the automation.
Actions (Then) | Run script: Use the same script as in [automation 1](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD#loioe51af489e10b4881960c990ec046e62f__automation-1).


